@@ -9,7 +9,7 @@ from python_framework.api.src.enumeration.HttpStatus import HttpStatus
 def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, status=HttpStatus.INTERNAL_SERVER_ERROR) :
     encapsulateItWithGlobalExceptionStatus = status
     def wrapper(function,*args,**kwargs) :
-        log.debug(wrapper, f'Wrapping {function} function with (*{args} args and **{kwargs} kwargs)')
+        log.wrapper(wrapper, f'Wrapping {function} function with (*{args} args and **{kwargs} kwargs)')
         def wrapedFunction(*args,**kwargs) :
             try :
                 functionReturn = function(*args,**kwargs)
@@ -18,7 +18,7 @@ def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, status=HttpStatus.
                     raise exception
                 logMessage = str(exception) if StringHelper.isNotBlank(str(exception)) else LOG_MESSAGE_NOT_PRESENT
                 functionName = ReflectionHelper.getName(function, typeName=c.TYPE_FUNCTION)
-                log.wraper(EncapsulateItWithGlobalException, f'''Failed to execute "{functionName}(args={args}, kwargs={kwargs})" {c.TYPE_FUNCTION} call''', exception)
+                log.wrapper(EncapsulateItWithGlobalException, f'''Failed to execute "{functionName}(args={args}, kwargs={kwargs})" {c.TYPE_FUNCTION} call''', exception)
                 raise GlobalException(
                     message=message,
                     logMessage=logMessage,
